abacusai.api_class.enums — AbacusAI documentation

# `abacusai.api_class.enums`

## Module Contents

### Classes

`ApiEnum` | Generic enumeration.
`SamplingMethodType` | Generic enumeration.

class abacusai.api_class.enums.ApiEnum

  Bases: `enum.Enum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  __eq__(other)

    Return self==value.

  __hash__()

    Return hash(self).

class abacusai.api_class.enums.SamplingMethodType

  Bases: `ApiEnum`

  Generic enumeration.

  Derive from this class to define new enumerations.

  N_SAMPLING = 'N_SAMPLING'
  PERCENT_SAMPLING = 'PERCENT_SAMPLING'